;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "flymake-eask" "20251231.1620"
  "Eask support in Flymake."
  '((emacs        "26.1")
    (flymake-easy "0.1"))
  :url "https://github.com/flymake/flymake-eask"
  :commit "b389846ee64cc56c25ffb162be4388f3f31ad809"
  :revdesc "b389846ee64c"
  :keywords '("lisp" "eask")
  :authors '(("Jen-Chieh" . "jcs090218@gmail.com"))
  :maintainers '(("Jen-Chieh" . "jcs090218@gmail.com")))
